@@ -35,7 +35,7 @@ import traceback
 import urllib.parse
 import warnings
 from functools import partialmethod
-from logging import error, info
+from logging import error, info, warning
 from typing import Generator, List, Optional, Text, Tuple, Set
 
 import requests
@@ -152,6 +152,10 @@ def handle_hexdigest(
     with no_ssl_verification():
         response = vtapi.get_file_report(hexdigest)
 
+    if 'results' not in response:
+        logging.error("%s in handle_hexdigest for %s", response, hexdigest)
+        sys.exit(1)
+
     if 'scans' not in response['results']:
         # VirusTotal has not seend this hexdigest before
         return
@@ -246,6 +250,9 @@ def handle_ip(actapi: act.api.Act, vtapi: VirusTotalApi, ip: Text, output_format
 
     if 'resolutions' in results:
         for resolution in results['resolutions']:
+            if not resolution['hostname']:
+                warning("Empty hostname in resolution: ip=%s, result=%s", ip, results)
+                continue
             act.api.helpers.handle_fact(actapi.fact('resolvesTo')
                                         .source('fqdn', resolution['hostname'])
                                         .destination(ip_type, ip),
